@@ -1,8 +1,10 @@
 context("read_arff")
 
+skip_if_not_installed("RWeka")
+
 test_that("Construct task from dict", {
   path = tempfile()
-  foreign::write.arff(iris, path)
+  RWeka::write.arff(iris, path)
   tab = read_arff(path)
   expect_data_table(tab, ncol = 5, nrow = 150, any.missing = FALSE)
   expect_factor(tab$Species)
